<template>
  <b-card-code title="">
    <div class="custom-search border rounded p-2">

      <!-- advance search input -->
      <b-row>
        <b-col md="4">
          <b-form-group>
            <label>產品編號</label>
            <b-form-input
              v-model="product.code"
              placeholder="Search"
              type="text"
              class="d-inline-block"
              @input="advanceSearch"
            />
          </b-form-group>
        </b-col>
        <b-col md="4">
          <b-form-group>
            <label>廠商代號</label>
            <b-form-select
              v-model="product.firm"
            >
              <b-form-select-option
              v-for="option in firmOptions"
              :key="option.id"
              :code="option.code"
              :value="option.id"
              >
                {{ option.name }}
              </b-form-select-option>
            </b-form-select>
          </b-form-group>
        </b-col>
        <b-col md="4">
          <b-form-group>
            <label>產品名稱</label>
            <b-form-input
              v-model="product.name"
              placeholder="Search"
              type="text"
              class="d-inline-block"
            />
          </b-form-group>
        </b-col>
        <b-col md="4">
          <b-form-group>
            <label>品牌</label>
            <b-form-select
              v-model="product.brand"
            >
              <b-form-select-option
              v-for="option in brandOptions"
              :key="option.id"
              :code="option.code"
              :value="option.id"
              >
                {{ option.name }}
              </b-form-select-option>
            </b-form-select>
          </b-form-group>
        </b-col>
        <b-col md="4">
          <b-form-group>
            <label>產品大類:</label>
            <b-form-select
              v-model="product.mainClass"
            >
              <b-form-select-option
              v-for="option in mainClassOptions"
              :key="option.id"
              :code="option.code"
              :value="option.id"
              >
                {{ option.name }}
              </b-form-select-option>
            </b-form-select>
          </b-form-group>
        </b-col>
        <b-col md="4">
          <b-form-group>
            <label>廠商貨號:</label>
            <b-form-input
              v-model="product.firmProductNumber"
              placeholder="Search"
              type="text"
              class="d-inline-block"
            />
          </b-form-group>
        </b-col>
      </b-row>
      <b-row>
        <b-col md="12">
          <b-button v-ripple.400="'rgba(255, 255, 255, 0.15)'" variant="primary float-right" @click="search()">
            搜尋
          </b-button>
          <!-- <b-button v-ripple.400="'rgba(255, 255, 255, 0.15)'" variant="primary float-right" @click="$router.push({ name: 'information-product-add'})">
            新增
          </b-button> -->
        </b-col>
      </b-row>
    </div>

    <!-- table -->
    <vue-good-table
      class="rounded p-2"
      :columns="columns"
      :rows="rows"
      :rtl="direction"
      :search-options="{
        enabled: true,
        externalQuery: searchTerm }"
      :pagination-options="{
        enabled: true,
        perPage:pageLength
      }"
      theme="my-theme"
    >
      <template
        slot="table-row"
        slot-scope="props"
      >
        <span
          v-if="props.column.field === 'action'"
          class="text-nowrap"
        >
        <b-dropdown
          variant="link"
          toggle-class="text-decoration-none"
          no-caret
        >
          <template v-slot:button-content>
            <feather-icon
              icon="MoreVerticalIcon"
              size="16"
              class="text-body align-middle mr-25"
            />
          </template>
          
          <b-dropdown-item :to="{ name: 'information-product-edit', params: { id: props.row.id } }">
            <feather-icon
              icon="Edit2Icon"
              class="mr-50"
            />
            <span>編輯</span>
          </b-dropdown-item>
        </b-dropdown>
        </span>
        
      </template>

      <!-- pagination -->
      <template
        slot="pagination-bottom"
        slot-scope="props"
      >
        <div class="d-flex justify-content-between flex-wrap">
          <div class="d-flex align-items-center mb-0 mt-1">
            <span class="text-nowrap">
              顯示 
            </span>
            <b-form-select
              v-model="pageLength"
              :options="['10','25','50','100']"
              class="mx-1"
              @input="(value)=>props.perPageChanged({currentPerPage:value})"
            />
            <span class="text-nowrap"> of {{ props.total }} 筆 </span>
          </div>
          <div>
            <b-pagination
              :value="1"
              :total-rows="props.total"
              :per-page="pageLength"
              first-number
              last-number
              align="right"
              prev-class="prev-item"
              next-class="next-item"
              class="mt-1 mb-0"
              @input="(value)=>props.pageChanged({currentPage:value})"
            >
              <template #prev-text>
                <feather-icon
                  icon="ChevronLeftIcon"
                  size="18"
                />
              </template>
              <template #next-text>
                <feather-icon
                  icon="ChevronRightIcon"
                  size="18"
                />
              </template>
            </b-pagination>
          </div>
        </div>
      </template>
      
    </vue-good-table>
  </b-card-code>
</template>

<script>
import BCardCode from '@core/components/b-card-code/BCardCode.vue'
import ToastificationContent from '@core/components/toastification/ToastificationContent.vue'
import { VueGoodTable } from 'vue-good-table'
import store from '@/store/index'
import axios from 'axios'
import vSelect from 'vue-select'
import { ref } from '@vue/composition-api'
import Ripple from 'vue-ripple-directive'
import { type } from 'os'

export default {
  components: {
    BCardCode,
    VueGoodTable,
    vSelect,
    ToastificationContent,
  },
  directives: {
    Ripple,
  },
  computed: {
    direction() {
      if (store.state.appConfig.isRTL) {
        this.dir = true
        return this.dir
      }
      this.dir = false
      return this.dir
    },
  },
  created() {
    this.getProductList();
    this.getFirms();
    this.getBrands();
    this.getProuductMain();
  },
  methods: {
    getProductList() {
        axios
          .get(this.apiProductUrl)
          .then((response) => {
            this.rows = response.data.data;
          })
    },
    getProuductMain() {
      axios
        .get('/api/v1/product/class/mains')
        .then((response) => {
          this.mainClassOptions = response.data.data;
        })
    },
    getFirms() {
      axios
        .get('/api/v1/product/firms')
        .then((response) => {
          this.firmOptions = response.data.data;
        })
    },
    getBrands() {
      axios
        .get('/api/v1/product/brands')
        .then((response) => {
          this.brandOptions = response.data.data;
        })
    },
    advanceSearch(val) {
      this.searchTerm = val
    },
    search() {
      axios
        .post('/api/v1/products/search',{'item' : this.product})
        .then((response) => {
            this.rows = response.data.data;
          })
    
    },
  },
  setup() {
    const searchTerm = ref(null);
    const pageLength = ref(10)
    const dir = ref(false)
    const columns = ref([
      { label: '產品編號', field: 'spu', }, 
      { label: '產品名稱', field: 'name_frontend', }, 
      { label: '庫存', field: 'stock', }, 
      { label: '廠商貨號', field: 'MPN', }, 
      { label: '產品大類', field: 'products_class_main_id', }, 
      { label: '規格', field: 'products_class_sub_id', }, 
      { label: '售價', field: 'price', }, 
      { label: '動作', field: 'action', } 
    ])

    const rows = ref([]);
    const product = ref({
      code: null,
      firm: null,
      name: null,
      mainClass: null,
      brand: null,
      firmProductNumber: null,
    })

    const mainClassOptions = ref({});
    const firmOptions = ref({});
    const brandOptions =ref({});
    const apiProductUrl = ref('/api/v1/products');

    return {
      pageLength,
      dir,
      columns,
      rows,
      searchTerm,
      apiProductUrl,
      product,
      mainClassOptions,
      brandOptions,
      firmOptions,
    }
  },
}
</script>
<style lang="scss" >
@import '~@resources/scss/vue/libs/vue-good-table.scss';
</style>